@@ -17,6 +17,8 @@ BEGIN {
     'WORKSHEET' => 'Excel::Template::Container::Worksheet',
 
     'CELL'      => 'Excel::Template::Element::Cell',
+    'COLUMN'    => 'Excel::Template::Element::Column',
+    'FORMULA'   => 'Excel::Template::Element::Formula',
     'VAR'       => 'Excel::Template::Element::Var',
 
     'FORMAT'    => 'Excel::Template::Container::Format',
@@ -43,9 +45,11 @@ BEGIN {
 );
 
 %isBuildable = map { $_ => 1 } qw(
-    CELL
     BOLD
+    CELL
+    COLUMN
     FORMAT
+    FORMULA
     IF
     ITALIC
     OUTLINE
